#[repr(C)]pub struct WlanPhyGetCountryResponse {
pub country: [u8; 2],
}Fields
country: [u8; 2]Trait Implementations
Sourceimpl Clone for WlanPhyGetCountryResponse
impl Clone for WlanPhyGetCountryResponse
Sourcefn clone(&self) -> WlanPhyGetCountryResponse
fn clone(&self) -> WlanPhyGetCountryResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WlanPhyGetCountryResponse
Sourceimpl Debug for WlanPhyGetCountryResponse
impl Debug for WlanPhyGetCountryResponse
Sourceimpl<___E> Encode<WlanPhyGetCountryResponse, ___E> for WlanPhyGetCountryResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanPhyGetCountryResponse, ___E> for WlanPhyGetCountryResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WlanPhyGetCountryResponse, WlanPhyGetCountryResponse>
const COPY_OPTIMIZATION: CopyOptimization<WlanPhyGetCountryResponse, WlanPhyGetCountryResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyGetCountryResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyGetCountryResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<WlanPhyGetCountryResponse, ___E> for &'a WlanPhyGetCountryResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanPhyGetCountryResponse, ___E> for &'a WlanPhyGetCountryResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyGetCountryResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyGetCountryResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, WlanPhyGetCountryResponse>, ___E> for WlanPhyGetCountryResponse
impl<___E> EncodeOption<Box<'static, WlanPhyGetCountryResponse>, ___E> for WlanPhyGetCountryResponse
Sourcefn encode_option(
this: Option<WlanPhyGetCountryResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WlanPhyGetCountryResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<WlanPhyGetCountryResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WlanPhyGetCountryResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, WlanPhyGetCountryResponse>, ___E> for &'a WlanPhyGetCountryResponsewhere
___E: Encoder + ?Sized,
&'a WlanPhyGetCountryResponse: Encode<WlanPhyGetCountryResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, WlanPhyGetCountryResponse>, ___E> for &'a WlanPhyGetCountryResponsewhere
___E: Encoder + ?Sized,
&'a WlanPhyGetCountryResponse: Encode<WlanPhyGetCountryResponse, ___E>,
Sourcefn encode_option(
this: Option<&'a WlanPhyGetCountryResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WlanPhyGetCountryResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a WlanPhyGetCountryResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WlanPhyGetCountryResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for WlanPhyGetCountryResponse
Sourceimpl FromWire<WlanPhyGetCountryResponse> for WlanPhyGetCountryResponse
impl FromWire<WlanPhyGetCountryResponse> for WlanPhyGetCountryResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WlanPhyGetCountryResponse, WlanPhyGetCountryResponse>
const COPY_OPTIMIZATION: CopyOptimization<WlanPhyGetCountryResponse, WlanPhyGetCountryResponse>
Sourcefn from_wire(wire: WlanPhyGetCountryResponse) -> WlanPhyGetCountryResponse
fn from_wire(wire: WlanPhyGetCountryResponse) -> WlanPhyGetCountryResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<WlanPhyGetCountryResponse> for WlanPhyGetCountryResponse
impl FromWireRef<WlanPhyGetCountryResponse> for WlanPhyGetCountryResponse
Sourcefn from_wire_ref(wire: &WlanPhyGetCountryResponse) -> WlanPhyGetCountryResponse
fn from_wire_ref(wire: &WlanPhyGetCountryResponse) -> WlanPhyGetCountryResponse
Converts the given reference to this type.
Sourceimpl Hash for WlanPhyGetCountryResponse
impl Hash for WlanPhyGetCountryResponse
Sourceimpl Ord for WlanPhyGetCountryResponse
impl Ord for WlanPhyGetCountryResponse
Sourcefn cmp(&self, other: &WlanPhyGetCountryResponse) -> Ordering
fn cmp(&self, other: &WlanPhyGetCountryResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WlanPhyGetCountryResponse
impl PartialEq for WlanPhyGetCountryResponse
Sourcefn eq(&self, other: &WlanPhyGetCountryResponse) -> bool
fn eq(&self, other: &WlanPhyGetCountryResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WlanPhyGetCountryResponse
impl PartialOrd for WlanPhyGetCountryResponse
impl StructuralPartialEq for WlanPhyGetCountryResponse