#[repr(C)]pub struct WlanPhySetCountryRequest {
pub country: [u8; 2],
}Fields
country: [u8; 2]Trait Implementations
Sourceimpl Clone for WlanPhySetCountryRequest
impl Clone for WlanPhySetCountryRequest
Sourcefn clone(&self) -> WlanPhySetCountryRequest
fn clone(&self) -> WlanPhySetCountryRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WlanPhySetCountryRequest
Sourceimpl Debug for WlanPhySetCountryRequest
impl Debug for WlanPhySetCountryRequest
Sourceimpl<___E> Encode<WlanPhySetCountryRequest, ___E> for WlanPhySetCountryRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanPhySetCountryRequest, ___E> for WlanPhySetCountryRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WlanPhySetCountryRequest, WlanPhySetCountryRequest>
const COPY_OPTIMIZATION: CopyOptimization<WlanPhySetCountryRequest, WlanPhySetCountryRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhySetCountryRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhySetCountryRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<WlanPhySetCountryRequest, ___E> for &'a WlanPhySetCountryRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanPhySetCountryRequest, ___E> for &'a WlanPhySetCountryRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhySetCountryRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhySetCountryRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, WlanPhySetCountryRequest>, ___E> for WlanPhySetCountryRequest
impl<___E> EncodeOption<Box<'static, WlanPhySetCountryRequest>, ___E> for WlanPhySetCountryRequest
Sourcefn encode_option(
this: Option<WlanPhySetCountryRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WlanPhySetCountryRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<WlanPhySetCountryRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WlanPhySetCountryRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, WlanPhySetCountryRequest>, ___E> for &'a WlanPhySetCountryRequest
impl<'a, ___E> EncodeOption<Box<'static, WlanPhySetCountryRequest>, ___E> for &'a WlanPhySetCountryRequest
Sourcefn encode_option(
this: Option<&'a WlanPhySetCountryRequest>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WlanPhySetCountryRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a WlanPhySetCountryRequest>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WlanPhySetCountryRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for WlanPhySetCountryRequest
Sourceimpl FromWire<WlanPhySetCountryRequest> for WlanPhySetCountryRequest
impl FromWire<WlanPhySetCountryRequest> for WlanPhySetCountryRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WlanPhySetCountryRequest, WlanPhySetCountryRequest>
const COPY_OPTIMIZATION: CopyOptimization<WlanPhySetCountryRequest, WlanPhySetCountryRequest>
Sourcefn from_wire(wire: WlanPhySetCountryRequest) -> WlanPhySetCountryRequest
fn from_wire(wire: WlanPhySetCountryRequest) -> WlanPhySetCountryRequest
Converts the given owned value to this type.
Sourceimpl FromWireRef<WlanPhySetCountryRequest> for WlanPhySetCountryRequest
impl FromWireRef<WlanPhySetCountryRequest> for WlanPhySetCountryRequest
Sourcefn from_wire_ref(wire: &WlanPhySetCountryRequest) -> WlanPhySetCountryRequest
fn from_wire_ref(wire: &WlanPhySetCountryRequest) -> WlanPhySetCountryRequest
Converts the given reference to this type.
Sourceimpl Hash for WlanPhySetCountryRequest
impl Hash for WlanPhySetCountryRequest
Sourceimpl Ord for WlanPhySetCountryRequest
impl Ord for WlanPhySetCountryRequest
Sourcefn cmp(&self, other: &WlanPhySetCountryRequest) -> Ordering
fn cmp(&self, other: &WlanPhySetCountryRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WlanPhySetCountryRequest
impl PartialEq for WlanPhySetCountryRequest
Sourcefn eq(&self, other: &WlanPhySetCountryRequest) -> bool
fn eq(&self, other: &WlanPhySetCountryRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WlanPhySetCountryRequest
impl PartialOrd for WlanPhySetCountryRequest
impl StructuralPartialEq for WlanPhySetCountryRequest