pub trait WlanPhyNotifyServerHandler<___T = Channel>where
___T: Transport,{
// Required methods
fn on_critical_error(
&mut self,
request: Request<OnCriticalError, ___T>,
responder: Responder<OnCriticalError, ___T>,
) -> impl Future<Output = ()> + Send;
fn on_country_code_change(
&mut self,
request: Request<OnCountryCodeChange, ___T>,
responder: Responder<OnCountryCodeChange, ___T>,
) -> impl Future<Output = ()> + Send;
// Provided method
fn on_unknown_interaction(
&mut self,
ordinal: u64,
) -> impl Future<Output = ()> + Send { ... }
}Expand description
A server handler for the WlanPhyNotify protocol.
See WlanPhyNotify for more details.
Required Methods
Sourcefn on_critical_error(
&mut self,
request: Request<OnCriticalError, ___T>,
responder: Responder<OnCriticalError, ___T>,
) -> impl Future<Output = ()> + Send
fn on_critical_error( &mut self, request: Request<OnCriticalError, ___T>, responder: Responder<OnCriticalError, ___T>, ) -> impl Future<Output = ()> + Send
Indicate to the receiver that the PHY has encountered a critical error specifying a reason code.
Sourcefn on_country_code_change(
&mut self,
request: Request<OnCountryCodeChange, ___T>,
responder: Responder<OnCountryCodeChange, ___T>,
) -> impl Future<Output = ()> + Send
fn on_country_code_change( &mut self, request: Request<OnCountryCodeChange, ___T>, responder: Responder<OnCountryCodeChange, ___T>, ) -> impl Future<Output = ()> + Send
Indicate to the receiver that the firmware running on wlan hardware has detected a change in country code.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".